@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::ResultSet;
 # ABSTRACT: A Result Set
-$MetaCPAN::Client::ResultSet::VERSION = '1.028003';
+$MetaCPAN::Client::ResultSet::VERSION = '2.000000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref >;
@@ -70,12 +70,6 @@ sub next {
     return $class->new_from_request( $result->{'_source'} || $result->{'fields'} );
 }
 
-sub facets {
-    my $self = shift;
-
-    return $self->has_scroller ? $self->scroller->facets : {};
-}
-
 sub aggregations {
     my $self = shift;
 
@@ -97,13 +91,13 @@ MetaCPAN::Client::ResultSet - A Result Set
 
 =head1 VERSION
 
-version 1.028003
+version 2.000000
 
 =head1 DESCRIPTION
 
 Object representing a result from Elastic Search. This is used for the complex
 (as in L<non-simple/MetaCPAN::Client/"SEARCH SPEC">) queries to MetaCPAN. It
-provides easy access to the scroller and facets.
+provides easy access to the scroller and aggregations.
 
 =head1 ATTRIBUTES
 
@@ -139,10 +133,6 @@ The entity of the result set. Available types:
 
 The aggregations available in the Elastic Search response.
 
-=head2 facets
-
-The facets available in the Elastic Search response.
-
 =head1 METHODS
 
 =head2 next
